@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::IRC::Plugin::BotCommand::AUTHORITY = 'cpan:HINRIK';
 }
 {
-  $POE::Component::IRC::Plugin::BotCommand::VERSION = '6.81';
+  $POE::Component::IRC::Plugin::BotCommand::VERSION = '6.82';
 }
 
 use strict;
@@ -194,7 +194,7 @@ sub _get_help {
         my $cmd = (split /\s+/, $args, 2)[0];
         if (exists $self->{Commands}->{$cmd}) {
             if (ref $self->{Commands}->{$cmd} eq 'HASH') {
-                push @help, "Syntax: $cmd ".
+                push @help, "Syntax: $p$cmd ".
                     (join ' ', @{ $self->{Commands}->{$cmd}->{args} }).
                     (defined $self->{Commands}->{$cmd}->{variable} ?
                         " ..."  : "");
